@@ -51,6 +51,7 @@ package com.openexchange.push.imapidle.osgi;
 
 import com.hazelcast.core.HazelcastInstance;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.context.ContextService;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.groupware.delete.DeleteListener;
@@ -91,7 +92,7 @@ public class ImapIdleActivator extends HousekeepingActivator {
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] { DatabaseService.class, TimerService.class, MailService.class, ConfigurationService.class, SessiondService.class,
-            ThreadPoolService.class, ContextService.class, UserService.class, PushListenerService.class };
+            ThreadPoolService.class, ContextService.class, UserService.class, PushListenerService.class, ConfigViewFactory.class };
     }
 
     @Override
